@@ -19,7 +19,7 @@ use Mozilla::PublicSuffix qw( public_suffix );
 use Try::Tiny;
 use Carp;
 
-our $VERSION = 'v2.2.0'; # VERSION
+our $VERSION = 'v2.3.0'; # VERSION
 # ABSTRACT: Representation of Registered eNom Domain
 
 has 'id' => (
@@ -134,7 +134,8 @@ sub construct_from_response {
             $is_private          = 0;
         }
         else {
-            $verification_status = $args{domain_info}{services}{entry}{raasettings}{raasetting}{verificationstatus};
+            # On verified domains the raasettings response is empty, if the value is missing, just call it verified.
+            $verification_status = $args{domain_info}{services}{entry}{raasettings}{raasetting}{verificationstatus} // 'Verified';
             $is_private          = ( $args{domain_info}{services}{entry}{wpps}{service}{content} == 1120 );
         }
 
